# Copyright (c) 2021-2023 Alibaba Cloud Computing Ltd.
# SPDX-License-Identifier: MulanPSL-2.0
# pylint: disable=C,redefined-outer-name,unspecified-encoding,import-error,logging-format-interpolation,broad-except,no-self-use,protected-access,abstract-method,consider-using-with,too-many-instance-attributes,too-many-arguments,eval-used,fixme,attribute-defined-outside-init
import re
import os
import logging

from agent.common.system import sysCommand
from agent.domain.base import BaseDomain
from agent.common.config import Config, ConfigFile

logger = logging.getLogger('common')


class Sysctl(BaseDomain):
    __domain__ = "sysctl"

    def __init__(self) -> None:
        super().__init__()

        # if KEEP_CONFIG is Ture, save config to /etc/sysctl.d/keentune.conf
        # if KEEP_CONFIG is False, define config_file incase rollback
        self.param_value_saved = {}
        self.config_file = ConfigFile.conf['sysctl']['CONFIG_FILE']
        self.config_file_head = "# This file is automatically generated by keentune-target\n\n"


    def post_setting(self):
        # if KEEP_CONFIG is Ture, save config to /etc/sysctl.d/keentune.conf
        if Config.KEEP_CONFIG:
            config_file_content = "\n".join(["{} = {}".format(k,v) for k,v in self.param_value_saved.items()])
            sysCommand("echo '{}' > {}".format(
                self.config_file_head + config_file_content, 
                self.config_file), log=True)


    def _set_value(self, param_name:str, param_value):
        if type(param_value) is str and not param_value.startswith("'"):
            param_value = "'" + param_value
        
        if type(param_value) is str and not param_value.endswith('\''):
            param_value = param_value + "'"
        
        if param_value == "":
            raise Exception("The parameter value is empty")
        
        assert re.match(r"^[\w\-\.]+$", param_name)
        assert re.match(r"^[\w\-\s'\"]+$", str(param_value))

        sysCommand("sysctl -w {param_name}={param_value}".format(
            param_name = param_name,
            param_value = param_value), log = True)
        
        self.param_value_saved[param_name] = param_value
        return param_value
    
    
    def _get_value(self, param_name:str):
        assert re.match(r"^[\w\-\.]+$", param_name)
        return sysCommand("sysctl -n {param_name}".format(param_name = param_name))


    def post_rollback(self):
        if os.path.exists(self.config_file):
            sysCommand("rm -f {}".format(self.config_file), log=True)
